@@ -6,6 +6,9 @@ import string
 
 import regex
 
+import packaging.version as p_version
+import packaging.specifiers as p_specifiers
+
 # This module is imported during synapse.__init__.  As such, we can't pull
 # arbitrary modules from Synapse here. synapse.exc is currently safe,
 # but we should not add other modules to this module.
@@ -118,8 +121,8 @@ def fmtVersion(*vsnparts):
 
     '''
     if len(vsnparts) < 1:
-        raise s_exc.BadTypeValu('Not enough version parts to form a version string with.',
-                                vsnparts=vsnparts)
+        raise s_exc.BadTypeValu(valu=repr(vsnparts), name='fmtVersion',
+                                mesg='Not enough version parts to form a version string with.',)
     ret = '.'.join([str(part).lower() for part in vsnparts])
     return ret
 
@@ -180,8 +183,34 @@ def parseVersionParts(text, seps=vseps):
     return ret
 
 
+def reqVersion(valu, reqver,
+               exc=s_exc.BadVersion,
+               mesg='Provided version does not match required version.'):
+    '''
+    Require a given version tuple is valid for a given requirements string.
+
+    Args:
+        valu (int, int, int): Major, minor and patch value to check.
+        reqver (str): A requirements version string.
+        exc (s_exc.SynErr): The synerr class to raise.
+        mesg (str): The message to pass in the exception.
+
+    Returns:
+        None: If the value is in bounds of minver and maxver.
+
+    Raises:
+        s_exc.BadVersion: If a precondition is incorrect or a version value is out of bounds.
+    '''
+
+    spec = p_specifiers.SpecifierSet(reqver)
+    verstr = fmtVersion(*valu)
+    vers = p_version.Version(verstr)
+
+    if vers not in spec:
+        raise exc(mesg=mesg, valu=valu, verstr=verstr, reqver=reqver)
+
 ##############################################################################
 # The following are touched during the release process by bumpversion.
 # Do not modify these directly.
-version = (0, 0, 36)
+version = (0, 1, 55)
 verstring = '.'.join([str(x) for x in version])
